@@ -1,15 +1,18 @@
 package Catalyst::Model::DBIC::Schema;
 
 use strict;
+use warnings;
+
+our $VERSION = '0.22';
+
 use base qw/Catalyst::Model Class::Accessor::Fast Class::Data::Accessor/;
-use NEXT;
+use MRO::Compat;
+use mro 'c3';
 use UNIVERSAL::require;
 use Carp;
 use Data::Dumper;
 require DBIx::Class;
 
-our $VERSION = '0.18';
-
 __PACKAGE__->mk_classaccessor('composed_schema');
 __PACKAGE__->mk_accessors('schema');
 
@@ -45,7 +48,7 @@ Actor in MyApp/Schema/FilmDB/Actor.pm:
 
   ...
 
-and a Role in MyApp/Schema/Role.pm:
+and a Role in MyApp/Schema/FilmDB/Role.pm:
 
   package MyApp::Schema::FilmDB::Role;
   use base qw/DBIx::Class/
@@ -80,7 +83,7 @@ See below for a full list of the possible config parameters.
 
 =back
 
-Now you have a working Model, accessing your separate DBIC Schema. Which can
+Now you have a working Model which accesses your separate DBIC Schema. This can
 be used/accessed in the normal Catalyst manner, via $c->model():
 
   my $actor = $c->model('FilmDB::Actor')->find(1);
@@ -100,10 +103,10 @@ Authentication::Store::DBIC in MyApp.pm:
       password_field  => 'password'
   }
 
-C<< $c->model() >> returns a L<DBIx::Class::ResultSet> for the source name
-parameter passed. To find out more about which methods can be called on a
-ResultSet, or how to add your own methods to it, please see the ResultSet
-documentation in the L<DBIx::Class> distribution.
+C<< $c->model('Schema::Source') >> returns a L<DBIx::Class::ResultSet> for 
+the source name parameter passed. To find out more about which methods can 
+be called on a ResultSet, or how to add your own methods to it, please see 
+the ResultSet documentation in the L<DBIx::Class> distribution.
 
 Some examples are given below:
 
@@ -141,6 +144,43 @@ This is a Catalyst Model for L<DBIx::Class::Schema>-based Models.  See
 the documentation for L<Catalyst::Helper::Model::DBIC::Schema> for
 information on generating these Models via Helper scripts.
 
+When your Catalyst app starts up, a thin Model layer is created as an 
+interface to your DBIC Schema. It should be clearly noted that the model 
+object returned by C<< $c->model('FilmDB') >> is NOT itself a DBIC schema or 
+resultset object, but merely a wrapper proving L<methods|/METHODS> to access 
+the underlying schema. 
+
+In addition to this model class, a shortcut class is generated for each 
+source in the schema, allowing easy and direct access to a resultset of the 
+corresponding type. These generated classes are even thinner than the model 
+class, providing no public methods but simply hooking into Catalyst's 
+model() accessor via the 
+L<ACCEPT_CONTEXT|Catalyst::Component/ACCEPT_CONTEXT> mechanism. The complete 
+contents of each generated class is roughly equivalent to the following:
+
+  package MyApp::Model::FilmDB::Actor
+  sub ACCEPT_CONTEXT {
+      my ($self, $c) = @_;
+      $c->model('FilmDB')->resultset('Actor');
+  }
+
+In short, there are three techniques available for obtaining a DBIC 
+resultset object: 
+
+  # the long way
+  my $rs = $c->model('FilmDB')->schema->resultset('Actor');
+
+  # using the shortcut method on the model object
+  my $rs = $c->model('FilmDB')->resultset('Actor');
+
+  # using the generated class directly
+  my $rs = $c->model('FilmDB::Actor');
+
+In order to add methods to a DBIC resultset, you cannot simply add them to 
+the source (row, table) definition class; you must define a separate custom 
+resultset class. See L<DBIx::Class::Manual::Cookbook/"Predefined searches"> 
+for more info.
+
 =head1 CONFIG PARAMETERS
 
 =over 4
@@ -154,7 +194,9 @@ C<Catalyst::Model::> namespace.  This parameter is required.
 =item connect_info
 
 This is an arrayref of connection parameters, which are specific to your
-C<storage_type> (see your storage type documentation for more details).
+C<storage_type> (see your storage type documentation for more details). 
+If you only need one parameter (e.g. the DSN), you can just pass a string 
+instead of an arrayref.
 
 This is not required if C<schema_class> already has connection information
 defined inside itself (which isn't highly recommended, but can be done)
@@ -163,11 +205,8 @@ For L<DBIx::Class::Storage::DBI>, which is the only supported
 C<storage_type> in L<DBIx::Class> at the time of this writing, the
 parameters are your dsn, username, password, and connect options hashref.
 
-If you need to specify the L<DBIx::Class::Storage::DBI> specific parameter
-C<on_connect_do>, or the related C<sql_maker> options C<limit_dialect>,
-C<quote_char>, or C<name_sep>, you can place these options into a hashref
-as the final element of the C<connect_info> arrayref.  If in doubt, don't
-specify these options.  You would know it if you needed them.
+See L<DBIx::Class::Storage::DBI/connect_info> for a detailed explanation
+of the arguments supported.
 
 Examples:
 
@@ -195,6 +234,28 @@ Examples:
                     }
                   ],
 
+Or using L<Config::General>:
+
+    <Model::FilmDB>
+        schema_class   MyApp::Schema::FilmDB
+        connect_info   dbi:Pg:dbname=mypgdb
+        connect_info   postgres
+        connect_info
+        <connect_info>
+            AutoCommit   0
+            on_connect_do   some SQL statement
+            on_connect_do   another SQL statement
+        </connect_info>
+    </Model::FilmDB>
+
+or
+
+    <Model::FilmDB>
+        schema_class   MyApp::Schema::FilmDB
+        connect_info   dbi:SQLite:dbname=foo.db
+    </Model::FilmDB>
+
+
 =item storage_type
 
 Allows the use of a different C<storage_type> than what is set in your
@@ -258,7 +319,7 @@ Used often for debugging and controlling transactions.
 =cut
 
 sub new {
-    my $self = shift->NEXT::new(@_);
+    my $self = shift->next::method(@_);
     
     my $class = ref($self);
     my $model_name = $class;
@@ -278,8 +339,8 @@ sub new {
         }
         else {
             croak "Either ->config->{connect_info} must be defined for $class"
-                  . " or $schema_class must have connect info defined on it"
-		  . "Here's what we got:\n"
+                  . " or $schema_class must have connect info defined on it."
+		  . " Here's what we got:\n"
 		  . Dumper($self);
         }
     }
@@ -290,7 +351,11 @@ sub new {
     $self->schema->storage_type($self->{storage_type})
         if $self->{storage_type};
 
-    $self->schema->connection(@{$self->{connect_info}});
+    $self->schema->connection( 
+        ref $self->{connect_info} eq 'ARRAY' ? 
+        @{$self->{connect_info}} : 
+        $self->{connect_info}
+    );
     
     no strict 'refs';
     foreach my $moniker ($self->schema->sources) {
